@@ -527,10 +527,12 @@ class Profile(LinkedIn):
         self.cookies = cookies
         self.headers = headers
 
-    def get_identity(self, profile_id=None, profile_urn=None):
-        lk_id = self.get_profile_id(profile_id)
-        url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}"
-        res = requests.get(url, cookies=self.cookies, headers=self.headers)
+    def get_identity(self, url=None, urn=None):
+        res_json = {}
+        result = {}
+        lk_id = self.get_profile_id(url)
+        req_url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}"
+        res = requests.get(req_url, cookies=self.cookies, headers=self.headers)
         try:
             res.raise_for_status()
         except requests.HTTPError as e:
@@ -547,7 +549,7 @@ class Profile(LinkedIn):
             "SUMMARY": data.get("summary"),
             "OCCUPATION": data.get("headline"),
             "INDUSTRY_NAME": data.get("industryName"),
-            "ADRESS": data.get("address"),
+            "ADDRESS": data.get("address"),
             "REGION": data.get("geoLocationName"),
             "COUNTRY": data.get("geoCountryName"),
             "LOCATION": data.get("locationName"),
@@ -555,10 +557,12 @@ class Profile(LinkedIn):
         }
         return pd.DataFrame([result])
 
-    def get_network(self, profile_id=None, profile_urn=None):
-        lk_id = self.get_profile_id(profile_id)
-        url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}/networkinfo"
-        res = requests.get(url, cookies=self.cookies, headers=self.headers)
+    def get_network(self, url=None, urn=None):
+        res_json = {}
+        result = {}
+        lk_id = self.get_profile_id(url)
+        req_url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}/networkinfo"
+        res = requests.get(req_url, cookies=self.cookies, headers=self.headers)
         try:
             res.raise_for_status()
         except requests.HTTPError as e:
@@ -579,10 +583,12 @@ class Profile(LinkedIn):
         }
         return pd.DataFrame([result])
 
-    def get_contact(self, profile_id=None, profile_urn=None):
-        lk_id = self.get_profile_id(profile_id)
-        url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}/profileContactInfo"
-        res = requests.get(url, cookies=self.cookies, headers=self.headers)
+    def get_contact(self, url=None, urn=None):
+        res_json = {}
+        result = {}
+        lk_id = self.get_profile_id(url)
+        req_url = f"https://www.linkedin.com/voyager/api/identity/profiles/{lk_id}/profileContactInfo"
+        res = requests.get(req_url, cookies=self.cookies, headers=self.headers)
         try:
             res.raise_for_status()
         except requests.HTTPError as e:
@@ -592,6 +598,11 @@ class Profile(LinkedIn):
         # Parse json
         data = res_json.get("data")
         # Specific
+        connected_at = data.get("connectedAt")
+        if connected_at is not None:
+            connected_at = datetime.fromtimestamp(int(str(connected_at)[:-3])).strftime(
+                "%Y-%m-%d %H:%M:%S"
+            )
         lk_phone = None
         lk_phones = data.get("phoneNumbers")
         if lk_phones is not None:
@@ -609,11 +620,9 @@ class Profile(LinkedIn):
             "PROFILE_URN": data.get("entityUrn").replace("urn:li:fs_contactinfo:", ""),
             "PROFILE_ID": lk_id,
             "EMAIL": data.get("emailAddress"),
-            "CONNECTED_AT": datetime.fromtimestamp(
-                int(str(data.get("connectedAt"))[:-3])
-            ).strftime("%Y-%m-%d %H:%M:%S"),
+            "CONNECTED_AT": connected_at,
             "BIRTHDATE": self.get_birthdate(data.get("birthDateOn")),
-            "ADRESS": data.get("address"),
+            "ADDRESS": data.get("address"),
             "TWITER": lk_twiter,
             "PHONENUMBER": lk_phone,
             "WEBSITES": data.get("websites"),
@@ -629,9 +638,10 @@ class Network(LinkedIn):
         self.headers = headers
 
     def get_followers(self, start=0, count=100, limit=-1):
-        url = f"{LINKEDIN_API}/network/getFollowers?start={start}&count={count}&limit={limit}"
+        res_json = {}
+        req_url = f"{LINKEDIN_API}/network/getFollowers?start={start}&count={count}&limit={limit}"
         headers = {"Content-Type": "application/json"}
-        res = requests.post(url, json=self.cookies, headers=headers)
+        res = requests.post(req_url, json=self.cookies, headers=headers)
         try:
             res.raise_for_status()
         except requests.HTTPError as e:
@@ -641,9 +651,10 @@ class Network(LinkedIn):
         return pd.DataFrame(res_json)
 
     def get_connections(self, start=0, count=100, limit=-1):
-        url = f"{LINKEDIN_API}/network/getConnections?start={start}&count={count}&limit={limit}"
+        res_json = {}
+        req_url = f"{LINKEDIN_API}/network/getConnections?start={start}&count={count}&limit={limit}"
         headers = {"Content-Type": "application/json"}
-        res = requests.post(url, json=self.cookies, headers=headers)
+        res = requests.post(req_url, json=self.cookies, headers=headers)
         try:
             res.raise_for_status()
         except requests.HTTPError as e:
